aboutsummaryrefslogtreecommitdiff
path: root/src/gr
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-22 09:41:13 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2002-04-22 09:41:13 +0000
commit206cfb86a5e8135d448fb62b5ed68afed7ea345e (patch)
treebb01f6bd5cf860ffd89c0d811e062093011a900e /src/gr
parent644a90a89e927e9f11337788163ef5977c7f416c (diff)
use *global* xyz positions to interpolate from Cactus grid
git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@557 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/gr')
-rw-r--r--src/gr/horizon_function.cc17
1 files changed, 10 insertions, 7 deletions
diff --git a/src/gr/horizon_function.cc b/src/gr/horizon_function.cc
index 68d2a94..c21bfad 100644
--- a/src/gr/horizon_function.cc
+++ b/src/gr/horizon_function.cc
@@ -136,13 +136,16 @@ CCTK_VInfo(CCTK_THORNSTRING, " xyz positions and derivative coefficients");
= p.ghosted_gridfn(ghosted_gfns::gfn__h, irho,isigma);
const fp rho = p.rho_of_irho(irho);
const fp sigma = p.sigma_of_isigma(isigma);
- fp x, y, z;
- p.xyz_of_r_rho_sigma(r,rho,sigma, x,y,z);
-
- // xyz positions of grid points
- p.gridfn(nominal_gfns::gfn__xx, irho,isigma) = x;
- p.gridfn(nominal_gfns::gfn__yy, irho,isigma) = y;
- p.gridfn(nominal_gfns::gfn__zz, irho,isigma) = z;
+ fp local_x, local_y, local_z;
+ p.xyz_of_r_rho_sigma(r,rho,sigma, local_x,local_y,local_z);
+ const fp global_x = ps.global_x_of_local_x(local_x);
+ const fp global_y = ps.global_y_of_local_y(local_y);
+ const fp global_z = ps.global_z_of_local_z(local_z);
+
+ // global xyz positions of grid points
+ p.gridfn(nominal_gfns::gfn__xx, irho,isigma) = global_x;
+ p.gridfn(nominal_gfns::gfn__yy, irho,isigma) = global_y;
+ p.gridfn(nominal_gfns::gfn__zz, irho,isigma) = global_z;
// 1st derivative coefficient gridfns X_ud
p.gridfn(nominal_gfns::gfn__X_ud_11, irho,isigma)